% this file calibrate the initial lambda and kappas by fitting PPP moments
% explicitly. That is, it calculate PPP in the model using the exact procedure
% used in the PWT. The benchmark calibration assumes that PPP equals the
% price index in the model. The analysis in the file shows that the later
% approach gives a very good approximation to the exact approach..

clear all
close all

global ep mu et th bt ga Ga1 Ga2 L N M adjust_w adjust_la imax toler

ep=1.01; % this code needs to be run with close to 1, as we assume ep=1 when
% calculating the fraction of non-tradable goods in the calculation of PPP in the model.
mu=.34;
% mu = 0.5;
th=4;
et=0.48;
% et = 0.5;

bt=.5;

adjust_w=.25; % update of the tatonnement process
adjust_la=.1; % update of the tatonnement process

Ga1=gamma(1+(1-ep)/th);

% gdp_type = 1; % output side
gdp_type = 0; % expenditure side


% load trade.txt
% load pwt.txt
% trade=load('trade_small.txt');
% pwt=load('pwt_small.txt');
% trade=load('trade_small_2.txt');
% pwt=load('pwt_small_2.txt');
trade=load('trade_small_3.txt');
% trade=load('trade_small_3_reexports_in.txt');
pwt=load('pwt_small_3.txt');
temp=load('deflator.txt');
deflator=temp(:,2);

tt=(1962:2000)';
T=length(tt);
N=length(trade(:,1))^.5;

% get indices corresponding to following countries in ii
ii=trade(1:N,2);
iUS=find(trade(1:N,2)==87);
iKorea=find(trade(1:N,2)==47);
iChina=find(trade(1:N,2)==15);
iTaiwan=find(trade(1:N,2)==77);
iThailand=find(trade(1:N,2)==79);
iBelgium=find(trade(1:N,2)==6);

% create [T,N] matrix for each variable in pwt
pop=reshape(pwt(:,2),T,N)';
emp=reshape(pwt(:,3),T,N)';
hc=reshape(pwt(:,4),T,N)';
gdpr=reshape(pwt(:,6),T,N)'*1000; %rgdpna
% output-side
if gdp_type == 1
    gdpn=reshape(pwt(:,8).*pwt(:,13),T,N)'*1000; % cgdpo*pl_gdpo
    gdpr0=reshape(pwt(:,8),T,N)'*1000;
    % expenditure-side
else
    gdpn=reshape(pwt(:,14).*pwt(:,15),T,N)'*1000; % cgdpe*pl_gdpe
    gdpr0=reshape(pwt(:,14),T,N)'*1000;
end
k=reshape(pwt(:,7),T,N)'*1000; % rkna, Capital stock at constant 2005 national prices (in mil. 2005US$)
k0=reshape(pwt(:,9),T,N)'*1000; % ck, Capital stock at current PPPs (in mil. 2005US$)
% gdpr=gdpr.*(gdpr0(:,1)*ones(1,T))./(gdpr(:,1)*ones(1,T));
k=k.*(k0(:,1)*ones(1,T))./(k(:,1)*ones(1,T));

% measure of equipped labor normalized by US
% L=k.^(1/3).*(pop.*hc).^(2/3);
% L=k.^(1/3).*(emp.*hc).^(2/3);
ze = 0.36;
L=k.^(ze).*(emp.*hc).^(1 - ze);


L=L/L(iUS,1);

% Real GDP per Capita normalized by US in 1962
y=(gdpr/gdpr(iUS,1))./L;
% y=(gdpr)./L;

% share of merchandixe imports at current PPP
m_gdp=reshape(pwt(:,10),T,N)';

% price level
% p_data=reshape(pwt(:,13),T,N)'; % pl_gdpo, Price level of CGDPo (PPP/XR),  price level of USA GDPo in 2005=1
p_data=reshape(pwt(:,15),T,N)'; % pl_gdpe, Price level of CGDPe (PPP/XR),  price level of USA GDPo in 2005=1
% % p_data=gdpn./gdpr;
p_data=p_data/p_data(iUS,1);

pppo_data=reshape(pwt(:,13),T,N)'; % pl_gdpe, Price level of CGDPe (PPP/XR),  price level of USA GDPo in 2005=1
pppo_data=pppo_data/pppo_data(iUS,1);

Y=gdpn./(ones(N,1)*p_data(iUS,:)); % exchange rate GDP, in dollars of 2005
Y=Y./Y(iUS,1);

% US real gdp growth
gUS=log(y(iUS,end)/y(iUS,1))/(T-1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                calculate trade shares and trade costs                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M=100000; % size of the montecarlo, i.e., number of goods

tic

for t=1:1%T
    temp=reshape(trade(:,t+2),N,N)';
    %     temp=reshape(trade(:,t+2),N,N)'*deflator(t);
    % temp=tril(temp)+tril(temp)';
    
    % calculate trade shares
    for i=1:N
        
        Exp(i,t) = sum(temp(i,:))-sum(temp(:,i))+gdpn(i,t)/(1-et);
        
        for j=1:N
            
            if j==i
                % [(gdpn of country i - sum exports of country i)/
                % (sum imports of country i + gdpn of country i - sum exports of country i)]
                
                PI_data(i,j)=(gdpn(i,t)/(1-et)-sum(temp(:,i)))...
                    /(sum(temp(i,:))-sum(temp(:,i))+gdpn(i,t)/(1-et));
                
            else
                % [(imports to country i from country j)/
                % (sum imports of country i + gdpn of country i - sum exports of country i)]
                PI_data(i,j)=temp(i,j)...
                    /(sum(temp(i,:))-sum(temp(:,i))+gdpn(i,t)/(1-et));
                
            end
            
        end
        
    end
    
    % reshape and store trade shares for each time period
    PI_t(:,t)=reshape(PI_data,N*N,1);
    
    for i=1:N
        % imports, imports/gdpn, exports of country i
        im(i,t)=sum(temp(i,:));
        im_gdpn(i,t)=sum(temp(i,:))/gdpn(i,t);
        ex(i,t)=sum(temp(:,i));
        
        
        %         [Z(i,t) fZ(i,t)]=fminbnd('eq_Z',0,1,[],imp(i,t)/gdpn(i,t));
        % m_E_data(i,t)=im(i,t)*deflator(t)/((im(i,t)-ex(i,t))*deflator(t)+gdpr(i,t)/(1-et));
        % m_E_data(i,t)=im(i,t)/((im(i,t)-ex(i,t))+gdpn(i,t)/(1-et));
        %         [Z(i,t) fZ(i,t)]=fminbnd('eq_Z_T',0,1,[],m_E_data(i,t));
        %         pi_ii_data(i,t)=((1-mu+mu*Z(i,t).^(1-(ep-1)/th))./(1-mu+mu*Z(i,t).^(-(ep-1)/th)));
        
        % Approximate Z(i,t) using tradables own share
        [Z(i,t) fZ(i,t)]=fminbnd('eq_Z_pi',0,1,[],PI_data(i,i));
        
        % own  share from data
        pi_ii_data(i,t)=PI_data(i,i);
        
        
        %         Tb(i,t)=(im(i,t)-ex(i,t))*deflator(t)/gdpr(i,t);
        %        Tb(i,t)=0;
        %         T(i,t)=(im(i,t)-ex(i,t))*deflator(t)/sum(gdpr(:,t));
        %         Tr(i,t)=(im(i,t)-ex(i,t))/sum(gdpn(:,t));
        %         Trdollars(i,t)=(im(i,t)-ex(i,t));
    end
    
    % share of country i's spending on non-tradable goods (see Appendix E)
    PI_NT_t(:,t)=(1-mu)./(1-mu+mu*Z(:,t).^(-(ep-1)/th));
    
    %share of country i's tradable spending on goods from country j
    PI_T=PI_data-diag(PI_NT_t(:,t));
    PI_T_t(:,t)=reshape(PI_T,N*N,1);
    
    Trdollars2(:,t)=inv(PI_data')*(gdpn(:,t)/(1-et)-PI_data'*gdpn(:,t)/(1-et));
    
    Trb(:,t)=Trdollars2(:,t)./gdpn(:,t);
    Tr(:,t)=Trdollars2(:,t)/sum(gdpn(:,t));
    
    K0=zeros(N,N);
    
    
    
    % We first calibrate the price index using PPP and expenditure information
    % from the PWT following the procedure described in the file PPP.pdf
    
    if t==1
        
        % calculate matrix A
        
        g2=1./(Ga1^(th/(ep-1)).*(1-mu+mu*Z(:,1).^(-(ep-1)/th)).^(th/(ep-1)));
        
        for i=1:N
            
            A(i,i)=g2(i)^(-1/th);
            
            for j=1:i-1
                
                g1(i,j)=((1-PI_data(i,i))/PI_data(i,j)*Z(i,t)/(1-Z(i,t)))^(1/th)...
                    *((1-mu+mu*Z(i,t)^(-(ep-1)/th))/(1-mu+mu*Z(j,t)^(-(ep-1)/th)))^(1/(ep-1));
                A(i,j)=g2(i)^(-1/th)*g1(i,j);
                
                
            end
            
            
            for j=i+1:N
                
                g1(i,j)=((1-PI_data(i,i))/PI_data(i,j)*Z(i,t)/(1-Z(i,t)))^(1/th)...
                    *((1-mu+mu*Z(i,t)^(-(ep-1)/th))/(1-mu+mu*Z(j,t)^(-(ep-1)/th)))^(1/(ep-1));
                A(i,j)=g2(i)^(-1/th)*g1(i,j);
                
                
            end
            
        end
        
        
        rng(1)
        % MxN matrix of random numbers uniformly distributed in [0,1].
        R=rand(M,N);
        
        % MxN matrix with the productivity of M potential producers in
        % the N countries, normalized by the stock of knowledge raised to 
        % the power 1/theta, u=q/lambda^(1/theta).
        u=(-(ones(M,N))./log(R)).^(1/th);
        
        % calculate the MxN r(u)=p_i(u)/p_i matrix
        
        for i=1:N
            
            % The first (1-mu)*M goods are assumed to be non-tradables.
            % For the remaining mu*M goods, the price in country i
            % is the minimum price of each of these goods over all
            % possible sources. To calculate these, we need to use
            % the matrix A.
            r_j_i(:,i)=[(ones(round((1-mu)*M),1)*(A(i,i))) ...
                ./u(1:round((1-mu)*M),i) ; ...
                min(ones(M-round((1-mu)*M),1)*A(i,:) ...
                ./u(round((1-mu)*M)+1:M,:),[],2)];
            
        end
        
        % vector of countries real expenditure relative to the real
        % expenditure in the world. This quantity is an intermediate input
        % in writting down the mapping between PPP and the theoretical 
        % price index.
        T_i=(Exp./p_data(:,1))/sum(Exp./pppo_data(:,1));
        

        % Initializing the vector of real expenditure.
        C0=Exp./p_data(:,1);
        
        % use an iterative procedure to solve for the theoretical price
        % index consistent with the PPP data, given the matrix r_j_i and 
        % the vector T_i.
        for iC=1:50
            
            temp=sum(r_j_i.^(-1)./sum(r_j_i.^(-1).*(ones(M,1)*C0'),2))/M;
            
            C1=T_i./temp';
            
            dist_C=(C1-C0)./C0;
            
            update_C=.5;
            
            C0=update_C*C1+(1-update_C)*C0;
            
            [iC min(dist_C) max(dist_C)]
            
            if max(abs(dist_C))<.001
                break
            end
            
            
        end
        
        % calculating the theoretical price index
        p0=Exp./C0;
                
        % calculate the value asymmetric iceberg trade costs consistent
        % with the trade data and the theoretical price index p0. We also
        % calculate the matrix of trade cost obtain if we assume that the
        % theoretical price index equal PPP in the PWT.
        for i=1:N
            
            for j=1:i-1
                
                K_PPP(i,j)=((1-PI_data(i,i))/PI_data(i,j)*Z(i,t)/(1-Z(i,t)))^(1/th)...
                    *p_data(i,1)/p_data(j,1)...
                    *((1-mu+mu*Z(i,t)^(-(ep-1)/th))/(1-mu+mu*Z(j,t)^(-(ep-1)/th)))^(1/(ep-1));
                K(i,j)=((1-PI_data(i,i))/PI_data(i,j)*Z(i,t)/(1-Z(i,t)))^(1/th)...
                    *p0(i)/p0(j)...
                    *((1-mu+mu*Z(i,t)^(-(ep-1)/th))/(1-mu+mu*Z(j,t)^(-(ep-1)/th)))^(1/(ep-1));
                
            end
            
            for j=i+1:N
                
                K_PPP(i,j)=((1-PI_data(i,i))/PI_data(i,j)*Z(i,t)/(1-Z(i,t)))^(1/th)...
                    *p_data(i,1)/p_data(j,1)...
                    *((1-mu+mu*Z(i,t)^(-(ep-1)/th))/(1-mu+mu*Z(j,t)^(-(ep-1)/th)))^(1/(ep-1));
                
                K(i,j)=((1-PI_data(i,i))/PI_data(i,j)*Z(i,t)/(1-Z(i,t)))^(1/th)...
                    *p0(i)/p0(j)...
                    *((1-mu+mu*Z(i,t)^(-(ep-1)/th))/(1-mu+mu*Z(j,t)^(-(ep-1)/th)))^(1/(ep-1));
                
            end
            
        end
        
        K0=K+eye(N);
        
        w=Y(:,1)./L(:,1); % calculate wages
        
        % calculate the value of the vector of stock of knowledge
        % consistent with the value of theoretical price index p0. We also
        % calculate the vector that is obtained if we assume that the
        % theoretical price index equal PPP in the PWT.
        la_PPP=(w./p_data(:,1)).^((1-et)*th)./(Ga1^(th/(ep-1)).*(1-mu+mu*Z(:,1).^(-(ep-1)/th)).^(th/(ep-1)));
        la0=(w./p0).^((1-et)*th)./(Ga1^(th/(ep-1)).*(1-mu+mu*Z(:,1).^(-(ep-1)/th)).^(th/(ep-1)));
        
        
    end
    
end

toc

p_data_1=p_data(:,1);

% Figure OA.7 in the online appendix.

figure(1)
X=[ones(N,1) log(p_data(:,1))];
[b_1 b_1_int R_1]=regress(log(p0),X);
temp=(R_1'*R_1)*inv(X'*X)/(N-2);
sb_1=diag(temp).^.5;
subplot(1,3,1)
% plot(log(p_data(:,1)),log(p1),'.',[-2 1.5],[-2 1.5],'r',[-2 1],b_1(1)+b_1(2)*[-2 1],'b')
plot(log(p_data(:,1)),log(p0),'o')
xlabel('$PPP$','Interpreter','Latex')
ylabel('theoretical price index, $p$ ','Interpreter','Latex')
% text(-.5,-1.5,['log p^{model} = ' num2str(b_1(1),3) '+' num2str(b_1(2),3) ' log PPP'])
axis([-2 1.5 -2 1.5])
title('Price Indices','Interpreter','Latex')
set(gca,'TickLabelInterpreter','latex')

subplot(1,3,2),plot(log(la0),log(la_PPP),'o')
axis([-6 0 -6 0])
xlabel('$\lambda$,  $p=PPP$','Interpreter','Latex')
ylabel('$\lambda$, $p$ theoretical','Interpreter','Latex')
title('Stock of Knowledge','Interpreter','Latex')
set(gca,'TickLabelInterpreter','latex')

subplot(1,3,3),plot(log(reshape(K0,N*N,1)),log(reshape(K_PPP,N*N,1)),'o')
axis([-2 10 -2 10])
xlabel('$\kappa$, $p=PPP$','Interpreter','Latex')
ylabel('$\kappa$, $p$ theoretical','Interpreter','Latex')
title('Trade Costs','Interpreter','Latex')
set(gca,'TickLabelInterpreter','latex')

