% This program calculate examples for a symmetric world
clear all
close all

global th bt ga n L al GA1 GA2 ps ep rh

warning off

options=optimset('Display','off');

nu=.02;
th=4;
ep=1.01;
ps=1;

n=50;

k1=1;

bt=.5;

ga=nu*th*(1-bt);
    
GA1=gamma(1-bt+(1-ep)/th);
GA2=gamma(1+(1-ep)/th);

al=1/(GA1/GA2*(1-bt)/ga*n^bt);

% Initial vector of lambdas
la1_ini=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *n^(bt/(1-bt));
lan_ini=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *n^(bt/(1-bt));

la1_FT=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *n^(bt/(1-bt));
lan_FT=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *n^(bt/(1-bt));

la_sym_prod=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *(1+(n-1)*k1^(-th))^(bt/(1-bt));

y_sym_prod=GA2^(-1/(1-ep))*la_sym_prod^(1/th)*(1+(n-1)*k1^(-th))^(1/th);

pi_sym=1/n;

la01=la1_FT;
la0n=lan_FT;

w_ini=1;

kn=100;
   
[tt Latt]=ode45(@(t,x) eq_la_producers_unif_k1_kn(t,x,[k1,kn],w_ini),[0 300],[la1_ini,lan_ini]);

la1=Latt(end,1);
lan=Latt(end,2);

la1_ini_prod=la1;
lan_ini_prod=lan;

temp=fminbnd('eq_w_k1_kn',0,1,options...
    ,[k1 kn],[la1 lan]);

wn=temp;

wn_ini=wn;

pi1_ini=la1/(la1+(n-2)*la1*k1^(-th)+lan*(wn*kn)^(-th));

pin_ini=lan*wn^(-th)/((n-1)*la1*kn^(-th)+lan*wn^(-th));

p1_ini=GA2^(1/(1-ep))*(la1+(n-2)*la1*k1^(-th)...
    +lan*(wn*kn)^(-th))^(-1/th);
pn_ini=GA2^(1/(1-ep))*((n-1)*la1*kn^(-th)+lan*wn^(-th))^(-1/th);


y1_ini_prod=1./p1_ini;
yn_ini_prod=wn./pn_ini;

[pi1_ini pin_ini lan_ini_prod/la_sym_prod yn_ini_prod/y_sym_prod]

kn=k1;

T=50;

sol_prod=ode45(@(t,x) eq_la_producers_unif_k1_kn(t,x,[k1,kn],w_ini),[0 200],[la1_ini_prod,lan_ini_prod]);

temp=deval(sol_prod,0:T)';

La1_prod(:,1)=temp(:,1);
Lan_prod(:,1)=temp(:,2);

for t=1:T

temp=fminbnd('eq_w_k1_kn',0,1.1,options...
    ,[k1 kn],[La1_prod(t) Lan_prod(t)]);

wn=temp;

Wn(t,1)=wn;
 
P1(t,1)=GA2^(1/(1-ep))*(La1_prod(t)+(n-2)*La1_prod(t)*k1^(-th)...
    +Lan_prod(t)*(wn*kn)^(-th))^(-1/th);
Pn(t,1)=GA2^(1/(1-ep))*((n-1)*La1_prod(t)*kn^(-th)...
    +Lan_prod(t)*wn^(-th))^(-1/th);

Yn_prod(t,1)=wn/Pn(t);

end

k1=1;

la_sym_sell=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *((1+(n-1)*k1^(-th*(1-bt)))/(1+(n-1)*k1^(-th))^(1-bt))^(1/(1-bt));

y_sym_sell=GA2^(-1/(1-ep))*la_sym_sell^(1/th)*(1+(n-1)*k1^(-th))^(1/th);

kn=100;

w_ini=1;

[tt Latt]=ode45(@(t,x) eq_la_sellers_k1_kn(t,x,[k1,kn],w_ini),[0 300],[la1_ini,lan_ini]);

la1=Latt(end,1);
lan=Latt(end,2);

la1_ini_sell=la1;
lan_ini_sell=lan;

temp=fminbnd('eq_w_k1_kn',0,1,options...
    ,[k1 kn],[la1 lan]);

wn=temp;

wn_ini=wn;

pi1_ini=la1/(la1+(n-2)*la1*k1^(-th)+lan*(wn*kn)^(-th));

pin_ini=lan*wn^(-th)/((n-1)*la1*kn^(-th)+lan*wn^(-th));

p1_ini=GA2^(1/(1-ep))*(la1+(n-2)*la1*k1^(-th)...
    +lan*(wn*kn)^(-th))^(-1/th);
pn_ini=GA2^(1/(1-ep))*((n-1)*la1*kn^(-th)+lan*wn^(-th))^(-1/th);


y1_ini_sell=1./p1_ini;
yn_ini_sell=wn./pn_ini;

[pi1_ini pin_ini lan_ini_sell/la_sym_sell yn_ini_sell/y_sym_sell]

kn=k1;

sol_sell=ode45(@(t,x) eq_la_sellers_k1_kn(t,x,[k1,kn],w_ini),[0 200],[la1_ini_sell,lan_ini_sell]);

temp=deval(sol_sell,0:T)';

La1_sell(:,1)=temp(:,1);
Lan_sell(:,1)=temp(:,2);

for t=1:T

temp=fminbnd('eq_w_k1_kn',0,1.1,options...
    ,[k1 kn],[La1_sell(t) Lan_sell(t)]);

wn=temp;

Wn(t,1)=wn;
 
P1(t,1)=GA2^(1/(1-ep))*(La1_sell(t)+(n-2)*La1_sell(t)*k1^(-th)...
    +Lan_sell(t)*(wn*kn)^(-th))^(-1/th);
Pn(t,1)=GA2^(1/(1-ep))*((n-1)*La1_sell(t)*kn^(-th)...
    +Lan_sell(t)*wn^(-th))^(-1/th);

Yn_sell(t,1)=wn/Pn(t);

end


figure(1)
subplot(1,2,1)
plot(0:T,Lan_sell.^(1/th)/la_sym_sell^(1/th),'b' ...
    ,0:T,Lan_prod.^(1/th)/la_sym_prod^(1/th),'r--' ...
    ,'LineWidth',2);
title('stock of ideas, \lambda_n^{1/\theta}','FontSize',12)
  axis([0 T 0.0 1.0])
  set(gca,'FontSize',12)
  legend('from sellers'...
      ,'from producers','Location','SouthEast')    
  legend boxoff

  xlabel('years','FontSize',12)

  subplot(1,2,2)
plot(1:T,Yn_sell./y_sym_sell,'b'...
    ,1:T,Yn_prod./y_sym_prod,'r--'...
,0,yn_ini_prod/y_sym_prod,'ro',0,yn_ini_sell/y_sym_sell,'bd'...
,'LineWidth',2);
title('per-capita income, y_n','FontSize',12)
  axis([0 T 0.0 1.0])
  set(gca,'FontSize',12)
  xlabel('years','FontSize',12)


  set(gcf, 'PaperPosition', [0 0 6 3]); %Position plot at left hand corner with width 5 and height 5.
set(gcf, 'PaperSize', [6 3]); %Set the paper to have width 5 and height 5.
% saveas(gcf,'figure_3_02','pdf') %Save figure
  
% Figure OA.15 in the online appendix

figure(2)
  subplot(1,2,1)
plot(1:T,Yn_sell./y_sym_sell,'b'...
    ,1:T,Yn_prod./y_sym_prod,'r--'...
,0,yn_ini_prod/y_sym_prod,'ro',0,yn_ini_sell/y_sym_sell,'bd'...
,'LineWidth',2);
title('Autarky to Costless Trade','FontSize',12)
  axis([0 T 0.0 1.0])
  set(gca,'FontSize',12)
  xlabel('years','FontSize',12)
  legend('from sellers'...
      ,'from producers','Location','SouthEast')    
  legend boxoff


load data_trans_cal

T=length(Yn_sell(:,1));
T0=50;

  subplot(1,2,2)
plot(1:T,Yn_sell(:,1)./y_sym_sell(1),'b'...
    ,1:T,Yn_sell(:,2)./y_sym_sell(2),'r'...
    ,1:T,Yn_sell(:,3)./y_sym_sell(3),'g'...
,0,yn_ini_sell(1)/y_sym_sell(1),'bd'...
,0,yn_ini_sell(2)/y_sym_sell(2),'rd'...
,0,yn_ini_sell(3)/y_sym_sell(3),'gd'...
,'LineWidth',2);
title('1-\pi_n = 0.05 \rightarrow 0.20','FontSize',12)
  axis([0 T0 0.8 1])
  set(gca,'FontSize',12)
  xlabel('years','FontSize',12)
  legend('\beta = 0.20'...
      ,'\beta = 0.50','\beta = 0.80','Location','SouthEast')    
  legend boxoff


  set(gcf, 'PaperPosition', [0 0 6 3]); %Position plot at left hand corner with width 5 and height 5.
set(gcf, 'PaperSize', [6 3]); %Set the paper to have width 5 and height 5.
% saveas(gcf,'figure_transition','pdf') %Save figure
