% This program calculate examples for a symmetric world
clear all
close all

global th bt ga n L al GA1 GA2 ps ep rh

warning off

options=optimset('Display','off');

nu=.02;
th=4;
ep=1.01;
ps=1;

n=50;

k1=2.65;

bt=.5;

gridbt=[.2 .5 .8];

for ibt=1:length(gridbt)

    bt=gridbt(ibt);
    
ga=nu*th*(1-bt);
    
GA1=gamma(1-bt+(1-ep)/th);
GA2=gamma(1+(1-ep)/th);

al=1/(GA1/GA2*(1-bt)/ga*n^bt);

% Initial vector of lambdas
la1_ini=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *n^(bt/(1-bt));
lan_ini=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *n^(bt/(1-bt));

la1_FT=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *n^(bt/(1-bt));
lan_FT=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *n^(bt/(1-bt));
la01=la1_FT;
la0n=lan_FT;

w_ini=1;

k1=3.7;

k1low=1;
k1high=10;
k1=.5*k1low+.5*k1high;

for ik1=1:15
    
    

knlow=1;
knhigh=10;
kn=.5*knlow+.5*knhigh;

for ikn=1:15

w_ini=1;

[tt Latt]=ode45(@(t,x) eq_la_sellers_k1_kn(t,x,[k1,kn],w_ini),[0:100:2000],[la1_ini,lan_ini]);

la1=Latt(end,1);
lan=Latt(end,2);

la1_ini_sell=la1;
lan_ini_sell=lan;

temp=fminbnd('eq_w_k1_kn',0,1,options...
    ,[k1 kn],[la1 lan]);

wn=temp;

wn_ini=wn;

pi1_ini=la1/(la1+(n-2)*la1*k1^(-th)+lan*(wn*kn)^(-th));

pin_ini=lan*wn^(-th)/((n-1)*la1*kn^(-th)+lan*wn^(-th));

p1_ini=GA2^(1/(1-ep))*(la1+(n-2)*la1*k1^(-th)...
    +lan*(wn*kn)^(-th))^(-1/th);
pn_ini=GA2^(1/(1-ep))*((n-1)*la1*kn^(-th)+lan*wn^(-th))^(-1/th);

diff=abs(pin_ini-.95);

% [ikn diff pin_ini]

if diff<.001
    break
end

if pin_ini<.95
knlow=kn;
kn=.5*knlow+.5*knhigh;
else
knhigh=kn;
kn=.5*knlow+.5*knhigh;    
end

end

diff=abs(pi1_ini-.8);

% [ik1 diff pi1_ini pin_ini]

if diff<.001
    break
end

if pi1_ini<.8
k1low=k1;
k1=.5*k1low+.5*k1high;
else
k1high=k1;
k1=.5*k1low+.5*k1high;    
end

end

kk1(ibt)=k1;
kkn(ibt)=kn;

la_sym_sell(ibt)=(al*GA1/GA2*(1-bt)/ga)^(1/(1-bt))...
    *((1+(n-1)*k1^(-th*(1-bt)))/(1+(n-1)*k1^(-th))^(1-bt))^(1/(1-bt));

y_sym_sell(ibt)=GA2^(-1/(1-ep))*la_sym_sell(ibt)^(1/th)*(1+(n-1)*k1^(-th))^(1/th);

y1_ini_sell(ibt)=1./p1_ini;
yn_ini_sell(ibt)=wn./pn_ini;

[tt Latt]=ode45(@(t,x) eq_la_sellers_k1_kn(t,x,[k1,kn],w_ini),[0:100:2000],[la1_ini,lan_ini]);

la1=Latt(end,1);
lan=Latt(end,2);

la1_ini_sell=la1;
lan_ini_sell=lan;

[pi1_ini pin_ini lan_ini_sell/la_sym_sell(ibt) yn_ini_sell/y_sym_sell]

T=300;

kn=k1;

sol_sell=ode45(@(t,x) eq_la_sellers_k1_kn(t,x,[k1,kn],w_ini),[0 300],[la1_ini_sell,lan_ini_sell]);

temp_lat=deval(sol_sell,0:T)';

La1_sell(:,ibt)=temp_lat(:,1);
Lan_sell(:,ibt)=temp_lat(:,2);

for t=1:T

temp=fminbnd('eq_w_k1_kn',0,1.1,options...
    ,[k1 kn],[La1_sell(t) Lan_sell(t)]);

wn=temp;

Wn(t,1)=wn;
 
P1(t,1)=GA2^(1/(1-ep))*(La1_sell(t)+(n-2)*La1_sell(t,ibt)*k1^(-th)...
    +Lan_sell(t,ibt)*(wn*kn)^(-th))^(-1/th);
Pn(t,1)=GA2^(1/(1-ep))*((n-1)*La1_sell(t,ibt)*kn^(-th)...
    +Lan_sell(t,ibt)*wn^(-th))^(-1/th);

Yn_sell(t,ibt)=wn/Pn(t);

end

end

T0=50;
% break

figure(1)
subplot(1,2,1)
plot(0:T,Lan_sell(:,1).^(1/th)/la_sym_sell(1)^(1/th),'b'...
    ,0:T,Lan_sell(:,2).^(1/th)/la_sym_sell(2)^(1/th),'r' ...
    ,0:T,Lan_sell(:,3).^(1/th)/la_sym_sell(3)^(1/th),'g','LineWidth',2);
title('stock of ideas, \lambda_n^{1/\theta}','FontSize',12)
  axis([0 T0 0.8 1])
  set(gca,'FontSize',12)
  legend('\beta = 0.20'...
      ,'\beta = 0.50','\beta = 0.80','Location','SouthEast')    
  legend boxoff

  xlabel('years','FontSize',12)

 
  subplot(1,2,2)
plot(1:T,Yn_sell(:,1)./y_sym_sell(1),'b'...
    ,1:T,Yn_sell(:,2)./y_sym_sell(2),'r'...
    ,1:T,Yn_sell(:,3)./y_sym_sell(3),'g'...
,0,yn_ini_sell(1)/y_sym_sell(1),'bd'...
,0,yn_ini_sell(2)/y_sym_sell(2),'rd'...
,0,yn_ini_sell(3)/y_sym_sell(3),'gd'...
,'LineWidth',2);
title('per-capita income, y_n','FontSize',12)
  axis([0 T0 0.8 1])
  set(gca,'FontSize',12)
  xlabel('years','FontSize',12)


  set(gcf, 'PaperPosition', [0 0 6 3]); %Position plot at left hand corner with width 5 and height 5.
set(gcf, 'PaperSize', [6 3]); %Set the paper to have width 5 and height 5.
% saveas(gcf,'figure_4_02','pdf') %Save figure
  
save data_trans_cal Yn_sell y_sym_sell yn_ini_sell

