% This program calculate examples for a symmetric world
clear all
close all

global th bt n

warning off

options=optimset('Display','off');

nu=.01;
th=4;
n=50;


gridbt=linspace(0,.99,20);
gridk=[1 1.2 2 5 10];

for ik=1:length(gridk)
    
    k=gridk(ik);

    for ibt=1:length(gridbt)

        bt=gridbt(ibt);

        [la(ik,ibt) f_la(ik,ibt)]=fminbnd('eq_lambda_core_peri_triangular',0,1,[],k);
        [w(ik,ibt) f_w(ik,ibt)]=fminbnd('eq_w_core_peri_triangular',0,1,[],k,la(ik,ibt));
        pi_ii_c(ik,ibt)=1/(1+(n-1)*k^(-th)+la(ik,ibt)*(w(ik,ibt)*k)^(-th)+(n-1)*la(ik,ibt)*(w(ik,ibt)*k^2)^(-th));
        pi_ii_p(ik,ibt)=la(ik,ibt)*w(ik,ibt)^(-th) ...
            /(k^(-th)+(n-1)*(k^2)^(-th)+la(ik,ibt)*w(ik,ibt)^(-th)+(n-1)*la(ik,ibt)*(w(ik,ibt)*k^2)^(-th));
        y(ik,ibt)=(la(ik,ibt)/(pi_ii_p(ik,ibt)/pi_ii_c(ik,ibt)))^(1/th);
    
end

end

figure(1)
subplot(1,3,1),plot(gridbt,y')
xlabel('\beta')
title('y_{p}/y_c')
legend(['\kappa = ' num2str(gridk(1))] ...
    ,['\kappa = ' num2str(gridk(2))] ...
    ,['\kappa = ' num2str(gridk(3))] ...
    ,['\kappa = ' num2str(gridk(4))] ...
    ,['\kappa = ' num2str(gridk(5))])
    
subplot(1,3,2),plot(gridbt,pi_ii_c)
xlabel('\beta')
title('\pi_{iic}')

subplot(1,3,3),plot(gridbt,pi_ii_p)
xlabel('\beta')
title('\pi_{iip}')

% Figure OA.16 in the online appendix

figure(2)

plot(gridbt,y(1,:),'b', ...
    gridbt,y(2,:),'r--', ...
    gridbt,100*y(3,:),'g-o', ...
    gridbt,100*y(4,:),'c-s', ...
    gridbt,100*y(5,:),'m-+', ...    
    gridbt,y(3,:),'g', ...
    gridbt,y(4,:),'c', ...
    gridbt,y(5,:),'m', ...
    gridbt(2:2:end),y(3,2:2:end),'go', ...
    gridbt,y(4,:),'cs', ...
    gridbt,y(5,:),'m+','LineWidth',2)
xlabel('\beta')
% title('y_{p}/y_c')
axis([0 1 0.5 1.1])
legend(['\kappa = ' num2str(gridk(1))] ...
    ,['\kappa = ' num2str(gridk(2))] ...
    ,['\kappa = ' num2str(gridk(3))] ...
    ,['\kappa = ' num2str(gridk(4))] ...
    ,['\kappa = ' num2str(gridk(5))],'Location','SouthWest')
legend boxoff
set(gca,'FontSize',12)

set(gcf, 'PaperPosition', [0 0 7.5 4.5]); %Position plot at left hand corner with width 5 and height 5.
set(gcf, 'PaperSize', [7.5 4.5]); %Set the paper to have width 5 and height 5.
set(gca,'FontSize',12)

